<?php

declare(strict_types=1);

namespace BezhanSalleh\FilamentShield\Forms;

use Filament\Forms\Components\Toggle;

class ShieldSelectAllToggle extends Toggle
{
    protected string $view = 'filament-shield::forms.shield-toggle';
}
